@@ -67,7 +67,7 @@ module Rouge
         end
 
         # White space and comments
-        rule(%r{[ \t\r]\/.*$}, Comment::Single)
+        rule(%r{\s+/.*}, Comment::Single)
         rule(/[ \t\r]+/, Text::Whitespace)
         rule(%r{^/$.*?^\\$}m, Comment::Multiline)
         rule(%r{^\/[^\n]*$(\n[^\S\n]+.*$)*}, Comment::Multiline)
@@ -110,7 +110,8 @@ module Rouge
       end
 
       state :string do
-        rule(/"/, Str, :pop!)
+        rule %r/\\"/, Str
+        rule %r/"/, Str, :pop!
         rule %r/\\([\\nr]|[01][0-7]{2})/, Str::Escape
         rule %r/[^\\"\n]+/, Str
         rule %r/\\/, Str # stray backslash
