@@ -1,4 +1,5 @@
 # -*- coding: utf-8 #
+# frozen_string_literal: true
 
 module Rouge
   module Lexers
@@ -35,96 +36,122 @@ module Rouge
       )
 
       state :root do
-        rule /(class|trait|object)(\s+)/ do
+        rule %r/(class|trait|object)(\s+)/ do
           groups Keyword, Text
           push :class
         end
-        rule /'#{idrest}[^']/, Str::Symbol
-        rule /[^\S\n]+/, Text
+        rule %r/'#{idrest}[^']/, Str::Symbol
+        rule %r/[^\S\n]+/, Text
 
-        rule %r(//.*?\n), Comment::Single
+        rule %r(//.*), Comment::Single
         rule %r(/\*), Comment::Multiline, :comment
 
-        rule /@#{idrest}/, Name::Decorator
+        rule %r/@#{idrest}/, Name::Decorator
+
+        rule %r/(def)(\s+)(#{idrest}|#{op}+|`[^`]+`)(\s*)/ do
+          groups Keyword, Text, Name::Function, Text
+        end
+
+        rule %r/(val)(\s+)(#{idrest}|#{op}+|`[^`]+`)(\s*)/ do
+          groups Keyword, Text, Name::Variable, Text
+        end
+
+        rule %r/(this)(\n*)(\.)(#{idrest})/ do
+          groups Keyword, Text, Operator, Name::Property
+        end
+
+        rule %r/(#{idrest}|_)(\n*)(\.)(#{idrest})/ do
+          groups Name::Variable, Text, Operator, Name::Property
+        end
+
+        rule %r/#{upper}#{idrest}\b/, Name::Class
+
+        rule %r/(#{idrest})(#{whitespace}*)(\()/ do
+          groups Name::Function, Text, Operator
+        end
+
+        rule %r/(\.)(#{idrest})/ do
+          groups Operator, Name::Property
+        end
+
         rule %r(
           (#{keywords.join("|")})\b|
           (<[%:-]|=>|>:|[#=@_\u21D2\u2190])(\b|(?=\s)|$)
         )x, Keyword
-        rule /:(?!#{op})/, Keyword, :type
-        rule /#{upper}#{idrest}\b/, Name::Class
-        rule /(true|false|null)\b/, Keyword::Constant
-        rule /(import|package)(\s+)/ do
+        rule %r/:(?!#{op})/, Keyword, :type
+        rule %r/(true|false|null)\b/, Keyword::Constant
+        rule %r/(import|package)(\s+)/ do
           groups Keyword, Text
           push :import
         end
 
-        rule /(type)(\s+)/ do
+        rule %r/(type)(\s+)/ do
           groups Keyword, Text
           push :type
         end
 
-        rule /""".*?"""(?!")/m, Str
-        rule /"(\\\\|\\"|[^"])*"/, Str
-        rule /'\\.'|'[^\\]'|'\\u[0-9a-fA-F]{4}'/, Str::Char
+        rule %r/""".*?"""(?!")/m, Str
+        rule %r/"(\\\\|\\"|[^"])*"/, Str
+        rule %r/'\\.'|'[^\\]'|'\\u[0-9a-fA-F]{4}'/, Str::Char
 
         rule idrest, Name
-        rule /`[^`]+`/, Name
+        rule %r/`[^`]+`/, Name
 
-        rule /\[/, Operator, :typeparam
-        rule /[\(\)\{\};,.#]/, Operator
-        rule /#{op}+/, Operator
+        rule %r/\[/, Operator, :typeparam
+        rule %r/[\(\)\{\};,.#]/, Operator
+        rule %r/#{op}+/, Operator
 
-        rule /([0-9][0-9]*\.[0-9]*|\.[0-9]+)([eE][+-]?[0-9]+)?[fFdD]?/, Num::Float
-        rule /([0-9][0-9]*[fFdD])/, Num::Float
-        rule /0x[0-9a-fA-F]+/, Num::Hex
-        rule /[0-9]+L?/, Num::Integer
-        rule /\n/, Text
+        rule %r/([0-9][0-9]*\.[0-9]*|\.[0-9]+)([eE][+-]?[0-9]+)?[fFdD]?/, Num::Float
+        rule %r/([0-9][0-9]*[fFdD])/, Num::Float
+        rule %r/0x[0-9a-fA-F]+/, Num::Hex
+        rule %r/[0-9]+L?/, Num::Integer
+        rule %r/\n/, Text
       end
 
       state :class do
-        rule /(#{idrest}|#{op}+|`[^`]+`)(\s*)(\[)/ do
+        rule %r/(#{idrest}|#{op}+|`[^`]+`)(\s*)(\[)/ do
           groups Name::Class, Text, Operator
           push :typeparam
         end
 
-        rule /\s+/, Text
-        rule /{/, Operator, :pop!
-        rule /\(/, Operator, :pop!
-        rule %r(//.*?\n), Comment::Single, :pop!
+        rule %r/\s+/, Text
+        rule %r/{/, Operator, :pop!
+        rule %r/\(/, Operator, :pop!
+        rule %r(//.*), Comment::Single, :pop!
         rule %r(#{idrest}|#{op}+|`[^`]+`), Name::Class, :pop!
       end
 
       state :type do
-        rule /\s+/, Text
-        rule /<[%:]|>:|[#_\u21D2]|forSome|type/, Keyword
-        rule /([,\);}]|=>|=)(\s*)/ do
+        rule %r/\s+/, Text
+        rule %r/<[%:]|>:|[#_\u21D2]|forSome|type/, Keyword
+        rule %r/([,\);}]|=>|=)(\s*)/ do
           groups Operator, Text
           pop!
         end
-        rule /[\(\{]/, Operator, :type
+        rule %r/[\(\{]/, Operator, :type
 
         typechunk = /(?:#{idrest}|#{op}+\`[^`]+`)/
-        rule /(#{typechunk}(?:\.#{typechunk})*)(\s*)(\[)/ do
+        rule %r/(#{typechunk}(?:\.#{typechunk})*)(\s*)(\[)/ do
           groups Keyword::Type, Text, Operator
           pop!
           push :typeparam
         end
 
-        rule /(#{typechunk}(?:\.#{typechunk})*)(\s*)$/ do
+        rule %r/(#{typechunk}(?:\.#{typechunk})*)(\s*)$/ do
           groups Keyword::Type, Text
           pop!
         end
 
-        rule %r(//.*?\n), Comment::Single, :pop!
-        rule /\.|#{idrest}|#{op}+|`[^`]+`/, Keyword::Type
+        rule %r(//.*), Comment::Single, :pop!
+        rule %r/\.|#{idrest}|#{op}+|`[^`]+`/, Keyword::Type
       end
 
       state :typeparam do
-        rule /[\s,]+/, Text
-        rule /<[%:]|=>|>:|[#_\u21D2]|forSome|type/, Keyword
-        rule /([\]\)\}])/, Operator, :pop!
-        rule /[\(\[\{]/, Operator, :typeparam
-        rule /\.|#{idrest}|#{op}+|`[^`]+`/, Keyword::Type
+        rule %r/[\s,]+/, Text
+        rule %r/<[%:]|=>|>:|[#_\u21D2]|forSome|type/, Keyword
+        rule %r/([\]\)\}])/, Operator, :pop!
+        rule %r/[\(\[\{]/, Operator, :typeparam
+        rule %r/\.|#{idrest}|#{op}+|`[^`]+`/, Keyword::Type
       end
 
       state :comment do
